@@ -1,6 +1,6 @@
-"""This module offers the DeepDiff, DeepSearch, grep and DeepHash classes."""
+"""This module offers the DeepDiff, DeepSearch, grep, Delta and DeepHash classes."""
 # flake8: noqa
-__version__ = '4.3.2'
+__version__ = '5.0.1'
 import logging
 
 if __name__ == '__main__':
@@ -10,3 +10,5 @@ if __name__ == '__main__':
 from .diff import DeepDiff
 from .search import DeepSearch, grep
 from .deephash import DeepHash
+from .delta import Delta
+from .path import extract
