@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 import re
 from collections.abc import MutableMapping, Iterable
+from ordered_set import OrderedSet
 import logging
 
-from deepdiff.helper import strings, numbers, add_to_frozen_set, get_doc
+from deepdiff.helper import strings, numbers, add_to_frozen_set, get_doc, dict_
 
 logger = logging.getLogger(__name__)
 
@@ -76,9 +77,9 @@ class DeepSearch(dict):
     def __init__(self,
                  obj,
                  item,
-                 exclude_paths=set(),
-                 exclude_regex_paths=set(),
-                 exclude_types=set(),
+                 exclude_paths=OrderedSet(),
+                 exclude_regex_paths=OrderedSet(),
+                 exclude_types=OrderedSet(),
                  verbose_level=1,
                  case_sensitive=False,
                  match_string=False,
@@ -93,9 +94,9 @@ class DeepSearch(dict):
         self.obj = obj
         self.case_sensitive = case_sensitive if isinstance(item, strings) else True
         item = item if self.case_sensitive else item.lower()
-        self.exclude_paths = set(exclude_paths)
+        self.exclude_paths = OrderedSet(exclude_paths)
         self.exclude_regex_paths = [re.compile(exclude_regex_path) for exclude_regex_path in exclude_regex_paths]
-        self.exclude_types = set(exclude_types)
+        self.exclude_types = OrderedSet(exclude_types)
         self.exclude_types_tuple = tuple(
             exclude_types)  # we need tuple for checking isinstance
         self.verbose_level = verbose_level
@@ -115,7 +116,7 @@ class DeepSearch(dict):
             del self[k]
 
     def __set_or_dict(self):
-        return {} if self.verbose_level >= 2 else set()
+        return dict_() if self.verbose_level >= 2 else OrderedSet()
 
     def __report(self, report_key, key, value):
         if self.verbose_level >= 2:
@@ -127,7 +128,7 @@ class DeepSearch(dict):
                      obj,
                      item,
                      parent,
-                     parents_ids=frozenset({}),
+                     parents_ids=frozenset(),
                      is_namedtuple=False):
         """Search objects"""
         found = False
@@ -174,7 +175,7 @@ class DeepSearch(dict):
                       obj,
                       item,
                       parent,
-                      parents_ids=frozenset({}),
+                      parents_ids=frozenset(),
                       print_as_attribute=False):
         """Search dictionaries"""
         if print_as_attribute:
@@ -182,7 +183,7 @@ class DeepSearch(dict):
         else:
             parent_text = "%s[%s]"
 
-        obj_keys = set(obj.keys())
+        obj_keys = OrderedSet(obj.keys())
 
         for item_key in obj_keys:
             if not print_as_attribute and isinstance(item_key, strings):
@@ -220,7 +221,7 @@ class DeepSearch(dict):
                           obj,
                           item,
                           parent="root",
-                          parents_ids=frozenset({})):
+                          parents_ids=frozenset()):
         """Search iterables except dictionaries, sets and strings."""
 
         for i, thing in enumerate(obj):
@@ -268,7 +269,7 @@ class DeepSearch(dict):
             self.__search_obj(
                 obj, item, parent, parents_ids, is_namedtuple=True)
 
-    def __search(self, obj, item, parent="root", parents_ids=frozenset({})):
+    def __search(self, obj, item, parent="root", parents_ids=frozenset()):
         """The main search method"""
 
         if self.__skip_this(item, parent):
